==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/CinderPersistentVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CinderPersistentVolumeSourceBuilder extends io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceFluentImpl<io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.CinderPersistentVolumeSource,io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceBuilder>{
  public CinderPersistentVolumeSourceBuilder() {
    this(false);
  }
  public CinderPersistentVolumeSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new CinderPersistentVolumeSource(), validationEnabled);
  }
  public CinderPersistentVolumeSourceBuilder(io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public CinderPersistentVolumeSourceBuilder(io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CinderPersistentVolumeSource(), validationEnabled);
  }
  public CinderPersistentVolumeSourceBuilder(io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.CinderPersistentVolumeSource instance) {
    this(fluent, instance, false);
  }
  public CinderPersistentVolumeSourceBuilder(io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.CinderPersistentVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFsType(instance.getFsType()); 
    fluent.withReadOnly(instance.getReadOnly()); 
    fluent.withSecretRef(instance.getSecretRef()); 
    fluent.withVolumeID(instance.getVolumeID()); 
    this.validationEnabled = validationEnabled; 
  }
  public CinderPersistentVolumeSourceBuilder(io.fabric8.kubernetes.api.model.CinderPersistentVolumeSource instance) {
    this(instance,false);
  }
  public CinderPersistentVolumeSourceBuilder(io.fabric8.kubernetes.api.model.CinderPersistentVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFsType(instance.getFsType()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withVolumeID(instance.getVolumeID()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.CinderPersistentVolumeSource build() {
    CinderPersistentVolumeSource buildable = new CinderPersistentVolumeSource(fluent.getFsType(),fluent.getReadOnly(),fluent.getSecretRef(),fluent.getVolumeID());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CinderPersistentVolumeSourceBuilder that = (CinderPersistentVolumeSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/CinderPersistentVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CinderPersistentVolumeSourceBuilder extends io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceFluentImpl<io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.CinderPersistentVolumeSource,io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceBuilder>{
  public CinderPersistentVolumeSourceBuilder() {
    this(false);
  }
  public CinderPersistentVolumeSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new CinderPersistentVolumeSource(), validationEnabled);
  }
  public CinderPersistentVolumeSourceBuilder(io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public CinderPersistentVolumeSourceBuilder(io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CinderPersistentVolumeSource(), validationEnabled);
  }
  public CinderPersistentVolumeSourceBuilder(io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.CinderPersistentVolumeSource instance) {
    this(fluent, instance, false);
  }
  public CinderPersistentVolumeSourceBuilder(io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.CinderPersistentVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFsType(instance.getFsType()); 
    fluent.withReadOnly(instance.getReadOnly()); 
    fluent.withSecretRef(instance.getSecretRef()); 
    fluent.withVolumeID(instance.getVolumeID()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CinderPersistentVolumeSourceBuilder(io.fabric8.kubernetes.api.model.CinderPersistentVolumeSource instance) {
    this(instance,false);
  }
  public CinderPersistentVolumeSourceBuilder(io.fabric8.kubernetes.api.model.CinderPersistentVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFsType(instance.getFsType()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withVolumeID(instance.getVolumeID()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.CinderPersistentVolumeSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.CinderPersistentVolumeSource build() {
    CinderPersistentVolumeSource buildable = new CinderPersistentVolumeSource(fluent.getFsType(),fluent.getReadOnly(),fluent.getSecretRef(),fluent.getVolumeID());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CinderPersistentVolumeSourceBuilder that = (CinderPersistentVolumeSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
